""" A NotificationCommand Command """
from cleo import Command
import os


class NotificationCommand(Command):
    """
    Creates a notification class.

    notification
        {name : Name of the notification to create.}
    """

    def handle(self):
        notification = self.argument('name')
        if not os.path.isfile('app/notifications/{0}.py'.format(notification)):
            if not os.path.exists(os.path.dirname('app/notifications/{0}.py'.format(notification))):
                # Create the path to the notification if it does not exist
                os.makedirs(os.path.dirname('app/notifications/{0}.py'.format(notification)))

            f = open('app/notifications/{0}.py'.format(notification), 'w+')

            f.write("''' A {0} Notification '''\n".format(notification))
            f.write('from notifications import Notifiable\n\n')
            f.write("class {0}(Notifiable):\n\n    def mail(self):\n        pass\n".format(notification))

            self.info('Notification Created Successfully!')
        else:
            self.error('Notification Already Exists!')


''' A NotificationProvider Service Provider '''
from masonite.provider import ServiceProvider
from notifications import Notify
from notifications.commands import NotificationCommand

class NotificationProvider(ServiceProvider):

    wsgi = False

    def register(self):
        self.app.bind('Notify', Notify(self.app))
        self.app.bind('NotificationCommand', NotificationCommand())

    def boot(self):
        pass



from setuptools import setup

setup(
    name='masonite-notifications',
    packages=[
        'notifications',
        'notifications.components',
        'notifications.snippets',
        'notifications.providers',
        'notifications.commands',
    ],
    version='0.0.4',
    install_requires=[],
    description='The core for the Masonite framework',
    author='Joseph Mancuso',
    author_email='idmann509@gmail.com',
    url='https://github.com/MasoniteFramework/notifications',
    keywords=['python web framework', 'python3', 'masonite'],
    classifiers=[],
    include_package_data=True,
)
